@@ -219,11 +219,11 @@ impl Session {
             sender, target_section_auth
         );
 
-        if let Some((session, elders, service_msg, mut dst_location, auth)) =
+        if let Some((msg_id, session, elders, service_msg, mut dst_location, auth)) =
             Self::new_elder_targets_if_any(
                 session.clone(),
                 bounced_msg.clone(),
-                &target_section_auth,
+                Some(&target_section_auth),
             )
             .await?
         {
@@ -243,7 +243,6 @@ impl Session {
 
             dst_location.set_section_pk(section_pk);
 
-            let msg_id = MessageId::new();
             // Let's rebuild the message with the updated destination details
             let wire_msg = WireMsg::new_msg(
                 msg_id,
@@ -253,13 +252,8 @@ impl Session {
             )?;
 
             debug!("Resending original message on AE-Redirect with updated details. Expecting an AE-Retry next");
-            send_message(elders.clone(), wire_msg, session.endpoint.clone(), msg_id).await?;
 
-            let _old_entry = session.ae_cache.write().await.insert((
-                dst_location.name(),
-                section_pk,
-                bounced_msg,
-            ));
+            send_message(elders.clone(), wire_msg, session.endpoint.clone(), msg_id).await?;
         }
 
         Ok(session)
@@ -273,10 +267,40 @@ impl Session {
         bounced_msg: Bytes,
         proof_chain: SecuredLinkedList,
     ) -> Result<Session, Error> {
+        // Update our network knowledge making sure proof chain
+        // validates the new SAP based on currently known remote section SAP.
+        match session.network.update(
+            SectionAuth {
+                value: section_auth.clone(),
+                sig: section_signed,
+            },
+            &proof_chain,
+        ) {
+            Ok(updated) => {
+                if updated {
+                    debug!(
+                        "Anti-Entropy: updated remote section SAP updated for {:?}",
+                        section_auth.prefix
+                    );
+                } else {
+                    debug!(
+                            "Anti-Entropy: discarded SAP for {:?} since it's the same as the one in our records: {:?}",
+                            section_auth.prefix, section_auth
+                        );
+                }
+            }
+            Err(err) => {
+                warn!(
+                        "Anti-Entropy: failed to update remote section SAP, bounced msg dropped. Failed section auth was {:?}, {:?}",
+                        err, section_auth
+                    );
+                return Ok(session);
+            }
+        }
+
         // Extract necessary information for resending
-        if let Some((session, elders, service_msg, mut dst_location, auth)) =
-            Self::new_elder_targets_if_any(session.clone(), bounced_msg.clone(), &section_auth)
-                .await?
+        if let Some((msg_id, session, elders, service_msg, dst_location, auth)) =
+            Self::new_elder_targets_if_any(session.clone(), bounced_msg.clone(), None).await?
         {
             debug!("Received AE-Retry with new SAP: {:?}", section_auth);
 
@@ -284,45 +308,9 @@ impl Session {
                 debug!("We have already responded to this message on an AE-Retry response. Dropping this instance");
                 return Ok(session);
             }
-            // Update our network knowledge making sure proof chain
-            // validates the new SAP based on currently known remote section SAP.
-            match session.network.update(
-                SectionAuth {
-                    value: section_auth.clone(),
-                    sig: section_signed,
-                },
-                &proof_chain,
-            ) {
-                Ok(updated) => {
-                    if updated {
-                        debug!(
-                            "Anti-Entropy: updated remote section SAP updated for {:?}",
-                            section_auth.prefix
-                        );
-                    } else {
-                        debug!(
-                                "Anti-Entropy: discarded SAP for {:?} since it's the same as the one in our records: {:?}",
-                                section_auth.prefix, section_auth
-                            );
-                    }
-                }
-                Err(err) => {
-                    warn!(
-                            "Anti-Entropy: failed to update remote section SAP, bounced msg dropped: {:?}, {:?}",
-                            err, service_msg
-                        );
-                    return Ok(session);
-                }
-            }
 
             let payload = WireMsg::serialize_msg_payload(&service_msg)?;
 
-            let target_section_pk = section_auth.public_key_set.public_key();
-            // Let's rebuild the message with the updated destination details
-            dst_location.set_section_pk(target_section_pk);
-
-            let msg_id = MessageId::new();
-
             let wire_msg = WireMsg::new_msg(
                 msg_id,
                 payload,
@@ -333,12 +321,6 @@ impl Session {
             debug!("Resending original message via AE-Retry");
 
             send_message(elders.clone(), wire_msg, session.endpoint.clone(), msg_id).await?;
-
-            let _old_entry = session.ae_cache.write().await.insert((
-                dst_location.name(),
-                target_section_pk,
-                bounced_msg,
-            ));
         }
 
         Ok(session)
@@ -348,9 +330,10 @@ impl Session {
     async fn new_elder_targets_if_any(
         session: Session,
         bounced_msg: Bytes,
-        received_auth: &SectionAuthorityProvider,
+        received_auth: Option<&SectionAuthorityProvider>,
     ) -> Result<
         Option<(
+            MessageId,
             Session,
             Vec<SocketAddr>,
             ServiceMsg,
@@ -359,7 +342,8 @@ impl Session {
         )>,
         Error,
     > {
-        let (msg_id, service_msg, dst_location, auth) =
+        let is_retry = received_auth.is_none();
+        let (msg_id, service_msg, mut dst_location, auth) =
             match WireMsg::deserialize(bounced_msg.clone())? {
                 MessageType::Service {
                     msg_id,
@@ -399,23 +383,51 @@ impl Session {
             }
         };
 
-        let mut target_elders = received_auth
-            .elders
-            .iter()
-            .sorted_by(|(lhs_name, _), (rhs_name, _)| {
-                dst_address_of_bounced_msg.cmp_distance(lhs_name, rhs_name)
-            })
-            .map(|(_, addr)| addr)
-            .take(target_count)
-            .cloned()
-            .collect::<Vec<SocketAddr>>();
+        let target_public_key;
 
-        let mut the_cache_guard = session.ae_cache.write().await;
+        // We normally have received auth when we're in AE-Redirect (where we could not trust enough to update our prefixmap)
+        let mut target_elders = if let Some(auth) = received_auth {
+            target_public_key = auth.public_key_set.public_key();
+            auth.elders
+                .iter()
+                .sorted_by(|(lhs_name, _), (rhs_name, _)| {
+                    dst_address_of_bounced_msg.cmp_distance(lhs_name, rhs_name)
+                })
+                .map(|(_, addr)| addr)
+                .take(target_count)
+                .cloned()
+                .collect::<Vec<SocketAddr>>()
+        } else {
+            // we use whatever is our latest knowledge at this point
+
+            if let Some(sap) = session
+                .network
+                .closest_or_opposite(&dst_address_of_bounced_msg)
+            {
+                target_public_key = sap.value.public_key_set.public_key();
+
+                sap.value
+                    .elders
+                    .values()
+                    .cloned()
+                    .take(target_count)
+                    .collect::<Vec<SocketAddr>>()
+            } else {
+                error!("Cannot resend, no 'received auth' provided, and nothing relevant in session network prefixmap");
+                return Ok(None);
+            }
+        };
+
+        let mut the_cache_guard = if is_retry {
+            session.ae_retry_cache.write().await
+        } else {
+            session.ae_redirect_cache.write().await
+        };
 
         let cache_entry = the_cache_guard.find(|x| {
             x == &(
-                dst_address_of_bounced_msg,
-                received_auth.public_key_set.public_key(),
+                target_elders.clone(),
+                target_public_key,
                 bounced_msg.clone(),
             )
         });
@@ -425,8 +437,17 @@ impl Session {
             debug!("Cache hit! We have sent this message before, removing target elders");
 
             target_elders = vec![];
+        } else {
+            let _old_entry_that_does_not_exist = the_cache_guard.insert((
+                target_elders.clone(),
+                target_public_key,
+                bounced_msg.clone(),
+            ));
         }
 
+        // Let's rebuild the message with the updated destination details
+        dst_location.set_section_pk(target_public_key);
+
         debug!(
             "Final target elders for resending {:?} message are {:?}",
             service_msg, target_elders
@@ -435,6 +456,7 @@ impl Session {
         drop(the_cache_guard);
 
         Ok(Some((
+            msg_id,
             session,
             target_elders,
             service_msg,
